==> knative-model-6.8.1-sources.jar: io/fabric8/knative/flows/v1/ParallelSubscriptionStatusFluent.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ParallelSubscriptionStatusFluent<A extends ParallelSubscriptionStatusFluent<A>> extends BaseFluent<A>{
  public ParallelSubscriptionStatusFluent() {
  }
  public ParallelSubscriptionStatusFluent(ParallelSubscriptionStatus instance) {
    instance = (instance != null ? instance : new ParallelSubscriptionStatus());

    if (instance != null) {
      this.withReady(instance.getReady());
      this.withSubscription(instance.getSubscription());
      this.withReady(instance.getReady());
      this.withSubscription(instance.getSubscription());
    }
  }
  private ConditionBuilder ready;
  private ObjectReferenceBuilder subscription;
  public Condition buildReady() {
    return this.ready!=null ?this.ready.build():null;
  }
  public A withReady(Condition ready) {
    _visitables.get("ready").remove(this.ready);
    if (ready!=null){ this.ready= new ConditionBuilder(ready); _visitables.get("ready").add(this.ready);} else { this.ready = null; _visitables.get("ready").remove(this.ready); } return (A) this;
  }
  public boolean hasReady() {
    return this.ready != null;
  }
  public ReadyNested<A> withNewReady() {
    return new ReadyNested(null);
  }
  public ReadyNested<A> withNewReadyLike(Condition item) {
    return new ReadyNested(item);
  }
  public ReadyNested<A> editReady() {
    return withNewReadyLike(java.util.Optional.ofNullable(buildReady()).orElse(null));
  }
  public ReadyNested<A> editOrNewReady() {
    return withNewReadyLike(java.util.Optional.ofNullable(buildReady()).orElse(new ConditionBuilder().build()));
  }
  public ReadyNested<A> editOrNewReadyLike(Condition item) {
    return withNewReadyLike(java.util.Optional.ofNullable(buildReady()).orElse(item));
  }
  public ObjectReference buildSubscription() {
    return this.subscription!=null ?this.subscription.build():null;
  }
  public A withSubscription(ObjectReference subscription) {
    _visitables.get("subscription").remove(this.subscription);
    if (subscription!=null){ this.subscription= new ObjectReferenceBuilder(subscription); _visitables.get("subscription").add(this.subscription);} else { this.subscription = null; _visitables.get("subscription").remove(this.subscription); } return (A) this;
  }
  public boolean hasSubscription() {
    return this.subscription != null;
  }
  public SubscriptionNested<A> withNewSubscription() {
    return new SubscriptionNested(null);
  }
  public SubscriptionNested<A> withNewSubscriptionLike(ObjectReference item) {
    return new SubscriptionNested(item);
  }
  public SubscriptionNested<A> editSubscription() {
    return withNewSubscriptionLike(java.util.Optional.ofNullable(buildSubscription()).orElse(null));
  }
  public SubscriptionNested<A> editOrNewSubscription() {
    return withNewSubscriptionLike(java.util.Optional.ofNullable(buildSubscription()).orElse(new ObjectReferenceBuilder().build()));
  }
  public SubscriptionNested<A> editOrNewSubscriptionLike(ObjectReference item) {
    return withNewSubscriptionLike(java.util.Optional.ofNullable(buildSubscription()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ParallelSubscriptionStatusFluent that = (ParallelSubscriptionStatusFluent) o;
    if (!java.util.Objects.equals(ready, that.ready)) return false;

    if (!java.util.Objects.equals(subscription, that.subscription)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ready,  subscription,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ready != null) { sb.append("ready:"); sb.append(ready + ","); }
    if (subscription != null) { sb.append("subscription:"); sb.append(subscription); }
    sb.append("}");
    return sb.toString();
  }
  public class ReadyNested<N> extends ConditionFluent<ReadyNested<N>> implements Nested<N>{
    ReadyNested(Condition item) {
      this.builder = new ConditionBuilder(this, item);
    }
    ConditionBuilder builder;
    public N and() {
      return (N) ParallelSubscriptionStatusFluent.this.withReady(builder.build());
    }
    public N endReady() {
      return and();
    }
    
  }
  public class SubscriptionNested<N> extends ObjectReferenceFluent<SubscriptionNested<N>> implements Nested<N>{
    SubscriptionNested(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    ObjectReferenceBuilder builder;
    public N and() {
      return (N) ParallelSubscriptionStatusFluent.this.withSubscription(builder.build());
    }
    public N endSubscription() {
      return and();
    }
    
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/flows/v1/ParallelSubscriptionStatusFluent.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ParallelSubscriptionStatusFluent<A extends ParallelSubscriptionStatusFluent<A>> extends BaseFluent<A>{
  public ParallelSubscriptionStatusFluent() {
  }
  
  public ParallelSubscriptionStatusFluent(ParallelSubscriptionStatus instance) {
    this.copyInstance(instance);
  }
  private ConditionBuilder ready;
  private ObjectReferenceBuilder subscription;
  
  protected void copyInstance(ParallelSubscriptionStatus instance) {
    instance = (instance != null ? instance : new ParallelSubscriptionStatus());
  
    if (instance != null) {
        this.withReady(instance.getReady());
        this.withSubscription(instance.getSubscription());
        this.withReady(instance.getReady());
        this.withSubscription(instance.getSubscription());
      }
  }
  
  public Condition buildReady() {
    return this.ready!=null ?this.ready.build():null;
  }
  
  public A withReady(Condition ready) {
    _visitables.get("ready").remove(this.ready);
    if (ready!=null){ this.ready= new ConditionBuilder(ready); _visitables.get("ready").add(this.ready);} else { this.ready = null; _visitables.get("ready").remove(this.ready); } return (A) this;
  }
  
  public boolean hasReady() {
    return this.ready != null;
  }
  
  public ReadyNested<A> withNewReady() {
    return new ReadyNested(null);
  }
  
  public ReadyNested<A> withNewReadyLike(Condition item) {
    return new ReadyNested(item);
  }
  
  public ReadyNested<A> editReady() {
    return withNewReadyLike(java.util.Optional.ofNullable(buildReady()).orElse(null));
  }
  
  public ReadyNested<A> editOrNewReady() {
    return withNewReadyLike(java.util.Optional.ofNullable(buildReady()).orElse(new ConditionBuilder().build()));
  }
  
  public ReadyNested<A> editOrNewReadyLike(Condition item) {
    return withNewReadyLike(java.util.Optional.ofNullable(buildReady()).orElse(item));
  }
  
  public ObjectReference buildSubscription() {
    return this.subscription!=null ?this.subscription.build():null;
  }
  
  public A withSubscription(ObjectReference subscription) {
    _visitables.get("subscription").remove(this.subscription);
    if (subscription!=null){ this.subscription= new ObjectReferenceBuilder(subscription); _visitables.get("subscription").add(this.subscription);} else { this.subscription = null; _visitables.get("subscription").remove(this.subscription); } return (A) this;
  }
  
  public boolean hasSubscription() {
    return this.subscription != null;
  }
  
  public SubscriptionNested<A> withNewSubscription() {
    return new SubscriptionNested(null);
  }
  
  public SubscriptionNested<A> withNewSubscriptionLike(ObjectReference item) {
    return new SubscriptionNested(item);
  }
  
  public SubscriptionNested<A> editSubscription() {
    return withNewSubscriptionLike(java.util.Optional.ofNullable(buildSubscription()).orElse(null));
  }
  
  public SubscriptionNested<A> editOrNewSubscription() {
    return withNewSubscriptionLike(java.util.Optional.ofNullable(buildSubscription()).orElse(new ObjectReferenceBuilder().build()));
  }
  
  public SubscriptionNested<A> editOrNewSubscriptionLike(ObjectReference item) {
    return withNewSubscriptionLike(java.util.Optional.ofNullable(buildSubscription()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ParallelSubscriptionStatusFluent that = (ParallelSubscriptionStatusFluent) o;
    if (!java.util.Objects.equals(ready, that.ready)) return false;
  
    if (!java.util.Objects.equals(subscription, that.subscription)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(ready,  subscription,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ready != null) { sb.append("ready:"); sb.append(ready + ","); }
    if (subscription != null) { sb.append("subscription:"); sb.append(subscription); }
    sb.append("}");
    return sb.toString();
  }
  public class ReadyNested<N> extends ConditionFluent<ReadyNested<N>> implements Nested<N>{
    ReadyNested(Condition item) {
      this.builder = new ConditionBuilder(this, item);
    }
    ConditionBuilder builder;
    
    public N and() {
      return (N) ParallelSubscriptionStatusFluent.this.withReady(builder.build());
    }
    
    public N endReady() {
      return and();
    }
    
  
  }
  public class SubscriptionNested<N> extends ObjectReferenceFluent<SubscriptionNested<N>> implements Nested<N>{
    SubscriptionNested(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    ObjectReferenceBuilder builder;
    
    public N and() {
      return (N) ParallelSubscriptionStatusFluent.this.withSubscription(builder.build());
    }
    
    public N endSubscription() {
      return and();
    }
    
  
  }

}
